@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 import unittest
 from pathlib import Path
-import time_track
+from bin import time_track
 
 
-class TestTPMFetch(unittest.TestCase):
+class TestTimeTrack(unittest.TestCase):
 
     def setUp(self):
         self.file = time_track.__file__
